# sciop-scraping

A (yet-to-be-named) tool to enable scraping of very large datasets to be distributed across multiple volunteers and then reassembled as dataset parts on [sciop](https://sciop.net).

**NB. this is currently a work in progress,** and it depends on planned features in [sciop](https://codeberg.org/safeguarding/sciop) that are not yet stabilised. If you're interested in contributing, experience of or interest in web scraping, Python CLI tools and/or REST APIs would be very helpful.

We absolutely want this to be as easy to use as possible, so as soon as we can we'll be adding detailed documentation and putting out a call for wider testing. Watch this space!

In the meantime, please [subscribe to the Safeguarding Research & Data forum](https://forum.safeguar.de) for pointers to datasets that need saving along with help & advice with collecting them, preparing for upload and creating torrents.
